// ========================================================================
// PHP ContactForm
// ------------------------------------------------------------------------
// https://www.dunweber.com/docs/scripts/releases/contactform
// Copyright (C) 2021 Christian L. Dünweber
// MIT License: https://opensource.org/licenses/MIT
// ========================================================================

class ContactForm
{
	// --------------------------------------------------------------------
	// Submit button clicked. Execute reCAPTCHA and submit form if passed.
	// --------------------------------------------------------------------
	submitForm(e)
	{
		e.preventDefault();

		if (window.navigator.onLine === false) {
			this.showMessage(cfForm.errorTitle.value, cfForm.errorConnection.value, 'errorText');
			return;
		}

		if (!cfForm.checkValidity()) {
			cfForm.reportValidity();
			return;
		}

		// Show activity while processing challenge
		cfForm.submitButton.innerHTML = '<span class="circle spinner"></span>';

		grecaptcha.ready(() => {
			try {
				grecaptcha.execute(cfForm.reCapSiteKey.value, {action: cfForm.reCapAction.value})
				.then((token) => { // Success: Challenge passed: Submit
					cfForm.reCapToken.value = token;
					cfForm.submit();
				})
				.catch(() => { // Error: Usually network connectivity: Inform to retry
					console.log('Possible issue communicating with reCAPTCHA');
					cfForm.submitButton.innerHTML = cfForm.submitButton.value;
					this.showMessage(cfForm.errorTitle.value, cfForm.errorGeneric.value, 'errorText');
				});
			}
			catch(err) { // Error: E.g. invalid reCAPTCHA site key: Inform about bad configuration
				console.log(err.message);
				cfForm.submitButton.innerHTML = cfForm.submitButton.value;
				this.showMessage(cfForm.errorTitle.value, cfForm.errorConfig.value, 'errorText');
			}
		});
	}

	// --------------------------------------------------------------------
	// Show message to the user. Adds a fieldset with title, body, and CSS
	// class above the form. A transition is triggered to catch attention.
	// --------------------------------------------------------------------
	showMessage(title, message, css)
	{
		let cfInfo = document.getElementById('cfInfo');

		if (cfInfo) {
			if (cfInfoBody.innerHTML !== message) {
				cfInfoBody.innerHTML = message;
			}

			this.triggerTransition(cfInfo);
			return;
		}
		
		cfInfo = document.createElement('fieldset');
		cfInfo.id = 'cfInfo';
		cfInfo.classList = css;
		cfInfo.innerHTML = '<legend id="cfInfoTitle">'+title+'</legend>'+
			'<div id="cfInfoBody">'+message+'</div>';
		cfForm.parentNode.insertBefore(cfInfo, cfForm);
		this.triggerTransition(cfInfo);
	}

	// --------------------------------------------------------------------
	// Trigger transition on elm by adding css class defining the effect
	// and triggering a reflow.
	// --------------------------------------------------------------------
	triggerTransition(elm)
	{
		window.location = window.location.origin + window.location.pathname + '#cfAnchor';
		elm.classList.add('transitionEffect');
		elm.focus(); // Trigger reflow
		elm.classList.remove('transitionEffect');
	}
}
